Orange Bioinformatics
=====================

Orange Bioinformatics is an add-on for Orange_ data mining software package. It
extends Orange by providing common functionality for basic tasks in
bioinformatics. It also provides widgets for Orange Canvas, which enable users
who are not programmers to manage microarray and genomic data flow and to
customize their analysis by combining common data analysis tools to fit their
needs.

.. _Orange: http://orange.biolab.si/

Documentation is found at:

http://orange-bioinformatics.readthedocs.org/

Installing
----------

To install Bioinformatics add-on for Orange run::

    python setup.py install

To build Python egg run::

    python setup.py bdist_egg

Installation for Developers
---------------------------

To install add-on in `development mode`_ run::

    python setup.py develop

.. _development mode: http://packages.python.org/distribute/setuptools.html#development-mode
